<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\ContactUs;
use App\Services\ApiCommonResponseService;
use App\Services\ContactUsService;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;



class ContactUsController extends Controller
{
    private $apiResponse;

    /**
     * Create a new locationservice instatnce
     *
     * @return void
     */
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();

    }

    public function store(Request $request){

        $validation = Validator::make($request->all(), [

            'name' => 'required',
            'contact_number' => 'required',
            'email' => 'required|email',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('200', 'Validation Error', $validation->errors());
        }


        $create_content_contact_us = ContactUs::create([
            'name' => $request->name,
            'designation' => $request->designation,
            'company' => $request->company,
            'contact_number' => $request->contact_number,
            'email' => $request->email,
            'subject' => $request->subject,
            'message' => $request->message
        ]);

        return $this->apiResponse->success_response('201','Content Successfully Created',$create_content_contact_us);

    }


    public function update(Request $request){

        $validation = Validator::make($request->all(), [

            'name' => 'required',
            'contact_number' => 'required',
            'email' => 'required',
            'subject' => 'required',
            'message' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());

        }

        $id = $request->id;
        $is_exists = ContactUs::find($id);

        if(!$is_exists){

            $code = '204';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code,$message,'Content Not Found');

        }

        $is_exists->update([
            'name' => $request->name,
            'designation' => $request->designation,
            'company' => $request->company,
            'contact_number' => $request->contact_number,
            'email' => $request->email,
            'subject' => $request->subject,
            'message' => $request->message
        ]);


        return $this->apiResponse->success_response('200','Content Successfully Updated',$is_exists);

    }


    public function delete(Request $request){

        $id = $request->id;
        $is_exists = ContactUs::find($id);

        if(!$is_exists){

            $code = '204';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code,$message,'Content Not Found');

        }

        $is_exists->delete();

        return $this->apiResponse->success_response('200','Content Successfully Deleted',$is_exists);

    }

    public function index(){

        $all_data_contact_us = ContactUs::all();
        return $this->apiResponse->success_response('200','Data Is Ready To Show',$all_data_contact_us);

    }
    public function makeContacted(Request $request){
        $id = $request->id;
        ContactUs::find($id)->update(['status'=> 1]);
        return $this->apiResponse->success_response('200','Data Changed Successfully',[]);

    }

}
