<?php

namespace App\Http\Controllers\Api;

use App\Models\Gallary;
use App\Services\ApiCommonResponseService;
use App\Services\ImageUploadService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class GallaryController extends Controller
{
    private $apiResponse, $photos_per_chunk = 20;

    /**
     * Create a new locationservice instatnce
     *
     * @return void
     */
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();

    }


    public function store(Request $request){

        $validation = Validator::make($request->all(), [

            'image' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }

        $file = $request->image;
        $path = 'images/tth/gallary/';
        $title = 'gallary_image_';
        $image_url = ImageUploadService::fileUploadWithDirCreate($path, $file, $title);

        $gallary_image = Gallary::create([
            'image' => $image_url,
            'caption' => $request->caption,
            'season'  => $request->season
        ]);

        return $this->apiResponse->success_response('200','Content Successfully Created',$gallary_image);

    }


    public function update(Request $request){

        $validation = Validator::make($request->all(), [

            'image' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());

        }

        try{
            $id = $request->id;
            $gallary_image = Gallary::find($id);

            if(!$gallary_image){

                $code = '200';
                $message = 'Content Not Found';

                return $this->apiResponse->error_response($code,$message,'Content Not Found');

            }

            $file = $request->image;
            $path = 'images/tth/gallary/';
            $title = 'gallary_image_';
            $image_url = ImageUploadService::fileUploadWithDirCreate($path, $file, $title);

            if (!empty($image_url)) {
                $gallary_image->image = $image_url;
                $gallary_image->save();
            }
            return $this->apiResponse->success_response(200, 'Gallary Updated successfully', $gallary_image);
        } catch (\Exception $e) {
            return $this->apiResponse->error_response(200, 'Update Failed. Please try again later', $e->getMessage());
        }


    }


    public function delete(Request $request){

        $id = $request->id;
        $is_exists = Gallary::find($id);

        if(!$is_exists){

            $code = '200';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code,$message,'Content Not Found');

        }

        $is_exists->delete();

        return $this->apiResponse->success_response('200','Content Successfully Deleted',$is_exists);

    }

    public function index(Request $request){
        $page_number = $request->page_number;
        if(!isset($page_number)){
            $page_number = 0;
        }
        $skip = $this->photos_per_chunk*$page_number;
        $all_data_gallary = Gallary::orderBy('id', 'desc')->skip($skip)->take($this->photos_per_chunk)->get();
        $count = Gallary::count();
        if( ($this->photos_per_chunk * ($request->page_number+1) ) > $count){
            $data['has_more'] = false;
        }
        else{
            $data['has_more'] = true;
        }
        $data['images'] = $all_data_gallary;
        return $this->apiResponse->success_response('200','Photos are retrived',$data);

    }
    public function getAllphoto(Request $request){
        $all_data_gallary = Gallary::orderBy('id', 'desc')->get();
        return $this->apiResponse->success_response('200','Data Is Ready To Show',$all_data_gallary);
    }
}
