<?php

namespace App\Http\Controllers\Api;

use App\Models\NoticeBoard;
use App\Services\ApiCommonResponseService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use PHPUnit\Framework\Error\Notice;

class NoticeBoardController extends Controller
{
    private $apiResponse;
    public $contects_per_chunks = 20;

    /**
     * Create a new locationservice instatnce
     *
     * @return void
     */
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();

    }


    public function store(Request $request){

        $validation = Validator::make($request->all(), [

            'title' => 'required',
            'description' => 'required',
            'notice_type' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());
        }

        $create_content_notice = NoticeBoard::create([
            'title' => $request->title,
            'description' => $request->description,
            'notice_type' => $request->notice_type,
            'is_pinned'   => $request->is_pinned
        ]);

        return $this->apiResponse->success_response('200','Content Successfully Created',$create_content_notice);

    }


    public function update(Request $request){

        $validation = Validator::make($request->all(), [

            'title' => 'required',
            'description' => 'required',
            'notice_type' => 'required'
        ]);

        if ($validation->fails()) {

            return $this->apiResponse->error_response('400', 'Validation Error', $validation->errors());

        }
        $id = $request->id;
        $is_exists = NoticeBoard::find($id);

        if(!$is_exists){

            $code = '200';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code,$message,'Content Not Found');

        }

        $is_exists->update([
            'title' => $request->title,
            'description' => $request->description,
            'notice_type' => $request->notice_type,
            'is_pinned'   => $request->is_pinned

        ]);


        return $this->apiResponse->success_response('200','Content Successfully Updated',$is_exists);

    }


    public function delete(Request $request){

        $id = $request->id;
        $is_exists = NoticeBoard::find($id);

        if(!$is_exists){

            $code = '200';
            $message = 'Content Not Found';

            return $this->apiResponse->error_response($code,$message,'Content Not Found');

        }

        $is_exists->delete();

        return $this->apiResponse->success_response('200','Content Successfully Deleted',$is_exists);

    }

    public function getNotice(Request $request){


        $all_notices = NoticeBoard::orderBy("id", "desc")->get();

        return $this->apiResponse->success_response('200','Data Is Ready To Show',$all_notices);

    }
    public function getCategoryWiseNotice(Request $request){
        if(!$request->notice_type){
            $page_number = $request->page_number;
            if (!isset($page_number)) {
                $page_number = 0;
            }
            $skip = $this->contects_per_chunks * $page_number;

            $all_data = NoticeBoard::orderBy('id', 'desc')->skip($skip)->take($this->contects_per_chunks)->get();
            $count = NoticeBoard::count();

            if (($this->contects_per_chunks * ($request->page_number + 1)) > $count) {
                $data['has_more'] = false;
            } else {
                $data['has_more'] = true;
            }
            $data['notices'] = $all_data;
            return $this->apiResponse->success_response('200', 'Notices are retrived', $data);
        }
        else{
            $page_number = $request->page_number;
            if (!isset($page_number)) {
                $page_number = 0;
            }
            $skip = $this->contects_per_chunks * $page_number;
            $notice_type = $request->notice_type;
            $all_data = NoticeBoard::where('notice_type', $notice_type)->orderBy('id', 'desc')->skip($skip)->take($this->contects_per_chunks)->get();
            $count = NoticeBoard::where('notice_type', $notice_type)->count();

            if (($this->contects_per_chunks * ($request->page_number + 1)) > $count) {
                $data['has_more'] = false;
            } else {
                $data['has_more'] = true;
            }
            $data['notices'] = $all_data;
            return $this->apiResponse->success_response('200', 'Category Notices are retrived', $data);

        }
    }
    public function getSingleNotice(Request $request){
            $notice = NoticeBoard::find($request->id);
            return $this->apiResponse->success_response('200', 'Notice is retrived', $notice);

    }
}
