<?php

namespace App\Http\Controllers\Api;

use App\Mail\PasswordResetToken;
use App\Services\ApiCommonResponseService;
use App\Services\ImageUploadService;
use App\Services\UserService;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Tymon\JWTAuth\Facades\JWTAuth;
use Illuminate\Support\Facades\Gate;

class UserInfoController extends Controller
{
    private $apiResponse;

    public function __construct()
    {

        $this->apiResponse = new ApiCommonResponseService();
        $this->userService = new UserService();

    }

    public function updatePassword(Request $request)
    {
        $validator = Validator::make($request->all(),
            [
                'old_password' => 'required',
                'new_password' => ['required', 'string', 'min:6', 'confirmed']
            ]);
        if ($validator->fails()) {
            $message = $validator->errors()->first();
            return $this->apiResponse->error_response(400, 'Validation Error', $message);
        }

        $newValidator = Validator::make($request->all(),
            [
                'new_password' => 'different:old_password',
            ]);
        if ($newValidator->fails()) {
            $message = $newValidator->errors()->first();
            return $this->apiResponse->error_response(400, 'New Password must be different from old password', $message);
        }

        $user = auth()->user();

        if (isset($user)) {
            $user = User::find($user->id);
            if (!empty($user)) {
                $flag = $this->userService->updatePassword($request, $user);
                if ($flag) return $this->apiResponse->success_response(200, 'User Successfully Updated', $flag);
                else return $this->apiResponse->error_response(400, 'Enter Wrong Current Password. Please try again later', 'Enter Wrong Current Password. Please try again later');

            } else {
                return $this->apiResponse->error_response('400', 'No user Found in Database', $user);
            }
        }
        return $this->apiResponse->error_response(200, 'Update Failed. Please try again later', 'Update Failed. Please try again later');
    }

    public function forgotPassword(Request $request)
    {
        $validator = Validator::make($request->all(),
            [
                'email' => 'required'
            ]);
        if ($validator->fails()) {
            $message = $validator->errors()->first();
            return $this->apiResponse->error_response(400, 'Validation Error', $validator->errors());
        }
        $email = $request->email;
        $user = User::where('email',$email)->first();

        if(!$user){
            return $this->apiResponse->error_response(400, 'No account', ['no_account' => ['No account Found associate to this mail . Please Enter Correct Mail']]);
        }
        try{

            $token = UserService::createToken($user);
            return $this->apiResponse->success_response(200, 'A token is sent to your email', $user);

        }catch(\Exception $e){
            return $this->apiResponse->error_response(400, 'No account Found associate to this mail . Please Enter Correct Mail', $e->getMessage());
        }
    }

    public function checkResetToken(Request $request)
    {
        $validator = Validator::make($request->all(),
            [
                'token' => 'required',
                'user_id' => 'required',
            ]);
        if ($validator->fails()) {
            $message = $validator->errors()->first();
            return $this->apiResponse->error_response(400, 'Validation Error', $message);
        }
        try{
            $user = User::where('reset_token',$request->token)->first();
            if (isset($user)){
                return $this->apiResponse->success_response(200, 'Token Matched', $user);
            }else{
                return $this->apiResponse->error_response(400, 'Token does not matched', $user);
            }

        }catch(\Exception $e){
            return $this->apiResponse->error_response(200, 'Update Failed. Please try again later', $e->getMessage());
        }
    }
    public function resetPassword(Request $request)
    {
        $validator = Validator::make($request->all(),
            [
                'new_password' => 'min:6|required_with:new_password_confirmation|same:new_password_confirmation',
                'new_password_confirmation' => 'min:6',
                'user_id' => 'required',
            ]);
        if ($validator->fails()) {
            $message = $validator->errors()->first();
            return $this->apiResponse->error_response(400, 'Validation Error', $message);
        }
        try{
            $user = User::where('id',$request->user_id)->first();
            if (isset($user)){
                $user->update(['password' => bcrypt($request->new_password)]);
                return $this->apiResponse->success_response(200, 'Password Updated Successfully', $user);
            }else{
                return $this->apiResponse->error_response(400, 'User is not found', $user);
            }

        }catch(\Exception $e){
            return $this->apiResponse->error_response(200, 'Update Failed. Please try again later', $e->getMessage());
        }
    }
    public function updateProfileImage(Request $request)
    {
        $validator = Validator::make($request->all(),
            [
                'image' => 'required|image',
            ]);
        if ($validator->fails()) {
            $message = $validator->errors()->first();
            return $this->apiResponse->error_response(400, 'Validation Error', $message);
        }
        try {
            $user_id = JWTAuth::parseToken()->authenticate()->id;


                $user = User::find($user_id);
                if (!empty($user)) {
                    $file = $request->image;
                    $path = 'images/tth/user/';
                    $title = 'pp_image_';
                    $image_url = ImageUploadService::fileUploadWithDirCreate($path, $file, $title);

                    if (!empty($image_url)) {
                        $user->image = $image_url;
                        $user->save();
                    }

                    $data=[
                      'id' => $user->id,
                      'name' => $user->user_name,
                      'email' => $user->email,
                      'tth_season' => $user->tth_season,
                      'father_name' => $user->father_name,
                      'mother_name' => $user->mother_name,
                      'tth_id' => $user->tth_id,
                      'institute_name' => $user->institute_name,
                      'image' => asset($user->image),
                      'f_name' => $user->f_name,
                      'l_name' => $user->l_name,
                      'phone' => $user->phone,
                      'address' => $user->address,
                      'designation' => $user->designation,
                      't_tth_season' => $user->t_tth_season,
                      'company' => $user->company,
                      'provider_id' => $user->provider_id,
                      'provider_name' => $user->provider_name,
                      'gender' => $user->gender,
                      'user_type' => $user->user_type,
                      'remember_token' => $user->remember_token,
                      'reset_token' => $user->reset_token,
                      'created_at' => $user->created_at,
                      'updated_at' => $user->updated_at,
                      'verify_token' => $user->verify_token,
                      'email_status' => $user->email_status,
                      'active_status' => $user->active_status,
                    ];
                    return $this->apiResponse->success_response(200, 'Profile Picture Updated successfully', $data);
                            }
        } catch (\Exception $e) {
            return $this->apiResponse->error_response(200, 'Update Failed. Please try again later', $e->getMessage());
        }
    }

    public function getParticipantCount(){
        $total_no_of_participants = User::where('user_type',4)->count();
        $total_no_of_judges = User::where('user_type',5)->count();
        $data=[
            'total_participants'=>$total_no_of_participants,
            'total_judges'=>$total_no_of_judges,
        ];
        return $this->apiResponse->success_response(200, 'Total Number of Participants & judges', $data);
    }

    public function getJudgeCount(){
        $total_no_of_judges = User::where('user_type',5)->count();
        return $this->apiResponse->success_response(200, 'Total Number of Judges', $total_no_of_judges);
    }
}
