<?php

namespace App\Http\Controllers\Api;

use App\Models\ExamVideo;
use App\Models\Result;
use App\Services\ApiCommonResponseService;
use App\Services\ResultService;
use App\User;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Tymon\JWTAuth\Facades\JWTAuth;

class VideoController extends Controller
{
    public  $result_per_page = 20, $apiResponse, $resultService;
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();
        $this->resultService = new ResultService();
    }
    public function get(Request $request){
        $id = $request->id;
        $video = ExamVideo::where('id','=', $id)->with('user')->first();
        $judge_name = null;
        if($video->judge_id){
            $judge_name = User::find($video->judge_id)->user_name;
        }

        $formated_data=[
            'id'=> $video->id,
            'is_youtube'=> $video->is_youtube,
            'is_drive'=> $video->is_drive,
            'user_name'=> $video->user->user_name,
            'zone'=> $video->user->zone->name,
            'video_link' => $video->video_link,
            'subject' => $video->video_type,
            'is_marked' => $video->is_marked,
            'marks' => $video->marks,
            'judge' => $judge_name,

        ];
        return $this->apiResponse->success_response('200','Waiting List of Admin Approval',$formated_data);
    }

    public function getUnassignedList(Request $request){
        $page_number = $request->page_number;
        if(!$page_number)
            $page_number = 1;
        $take = $this->result_per_page;
        $skip = ($page_number - 1) * $take;
        if($request->search && $request->zone_id)
        {

            $videos=ExamVideo::with('user')->whereHas('user',function($query) use($request) {
              $query->where('zone_id',$request->zone_id)->where(function ($q) use($request){
                  return $q->where('tth_id', 'like', '%' . $request->search . '%')->orwhere('user_name', 'like', '%' . $request->search . '%');
              });
            })->where('is_marked','=', 0)->skip($skip)->take($take)->get();

            $total_count = ExamVideo::with('user')->whereHas('user',function($query) use($request) {
                $query->where('zone_id',$request->zone_id)->where(function ($q) use($request){
                    return $q->where('tth_id', 'like', '%' . $request->search . '%')->orwhere('user_name', 'like', '%' . $request->search . '%');
                });
            })->where('is_marked','=', 0)->skip($skip)->take($take)->count();
        }
        elseif($request->search)
        {
            $videos=ExamVideo::with('user')->whereHas('user',function($query) use($request) {
                $query->where(function ($q) use($request){
                    return $q->where('tth_id', 'like', '%' . $request->search . '%')->orwhere('user_name', 'like', '%' . $request->search . '%');
                });
            })->where('is_marked','=', 0)->skip($skip)->take($take)->get();

            $total_count = ExamVideo::with('user')->whereHas('user',function($query) use($request) {
                $query->where(function ($q) use($request){
                    return $q->where('tth_id', 'like', '%' . $request->search . '%')->orwhere('user_name', 'like', '%' . $request->search . '%');
                });
            })->where('is_marked','=', 0)->skip($skip)->take($take)->count();

        }
        elseif($request->zone_id)
        {
            $videos=ExamVideo::with('user')->whereHas('user',function($query) use($request) {
                $query->where('zone_id',$request->zone_id);
            })->where('is_marked','=', 0)->skip($skip)->take($take)->get();

            $total_count = ExamVideo::with('user')->whereHas('user',function($query) use($request) {
                $query->where('zone_id',$request->zone_id);
            })->where('is_marked','=', 0)->skip($skip)->take($take)->count();
        }
        else
        {

            $videos=ExamVideo::where('is_marked','=', 0)->with('user')->skip($skip)->take($take)->get();
            $total_count = ExamVideo::where('is_marked','=',0)->count();
        }
        /*$videos=ExamVideo::where('is_marked','=', 0)->with('user')->skip($skip)->take($take)->get();*/
        $formated_data = $this->cleanData($videos);
        $formated_data = $this->apiResponse->pagination($formated_data, $page_number ,$total_count, $this->result_per_page);
        return $this->apiResponse->success_response('200','Waiting List of Admin Approval',$formated_data);
    }
    public function getAssignedList(Request $request){
        $page_number = $request->page_number;
        if(!$page_number)
            $page_number = 1;
        $take = $this->result_per_page;
        $skip = ($page_number - 1) * $take;
        $videos=ExamVideo::where('is_marked','=', 1)->with('user')->skip($skip)->take($take)->get();
        $total_count = ExamVideo::where('is_marked','=',1)->count();
        $formated_data = $this->cleanData($videos);
        $formated_data = $this->apiResponse->pagination($formated_data, $page_number ,$total_count, $this->result_per_page);
        return $this->apiResponse->success_response('200','Waiting List of Admin Approval',$formated_data);
    }
    public function giveMarks(Request $request){
        $user = JWTAuth::parseToken()->authenticate();
        $video_id = $request->id;
        $video = ExamVideo::find($video_id);
        ExamVideo::find($video_id)->update([
           'is_marked' => true,
           'judge_id' => $user->id,
           'marks' => $request->marks
        ]);
        $this->resultService->assignVideoAUditionMarks($user->id, $request->marks);
        return $this->apiResponse->success_response('200','Waiting List of Admin Approval','Marks Given Successfullt');

    }

    public function cleanData($video_list){
        $data=[];
        foreach($video_list as $list)
        {
            $data[]=[
                'id'=>$list->id,
                'is_youtube'=>$list->is_youtube,
                'user_name'=>$list->user->user_name,
                'tth_id'=>$list->user->tth_id,
                'zone'=>$list->user->zone->name,
                'subject' => $list->video_type,
                'marks' => $list->marks,
                'is_drive' => $list->is_drive
            ];
        }
        return $data;
    }
}
