<?php

namespace App\Http\Controllers\Api;

use App\Models\Zone;
use App\Services\ApiCommonResponseService;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class ZoneController extends Controller
{
    private $apiResponse;
    public function __construct()
    {
        $this->apiResponse = new ApiCommonResponseService();
    }

    public function create(Request $request){
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'exam_time' => 'required',
            'exam_date' => 'required'

        ]);

        if ($validator->fails()) {

            $message = $validator->errors()->first();
            return $this->apiResponse->error_response('500', 'Validation Error', $validator->errors());

        }
        Zone::create([
            'name' => $request->name,
            'exam_time' => $request->exam_time,
            'exam_date' => $request->exam_date
        ]);
        return $this->apiResponse->success_response(200, 'Zone Created' , []);
    }
    public function update(Request $request){
        Zone::where('id', $request->id)->update([
            'name' => $request->name,
            'exam_time' => $request->exam_time,
            'exam_date' => $request->exam_date,
            'is_active' => $request->is_active
        ]);
        return $this->apiResponse->success_response(200, 'Zone Updated' , []);
    }
    public function delete(Request $request){
        Zone::where('id', $request->id)->delete();
        return $this->apiResponse->success_response(200, 'Zone Deleted' , []);
    }
    public function get(){
        $all_zone = Zone::all();
        return $this->apiResponse->success_response(200, 'Zone Fetched' , $all_zone);

    }
    public function getActiveZone(){
        $all_zone = Zone::where('is_active', 1)->get();
        return $this->apiResponse->success_response(200, 'Zone Fetched' , $all_zone);
    }
}
