<?php
/**
 * Created by PhpStorm.
 * User: charlie
 * Date: 10/18/18
 * Time: 3:07 PM
 */

namespace App\Services;


use App\Mail\PasswordResetToken;
use App\Models\AppUser;
use App\Models\TthUser;
use App\User;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;


class UserService
{

    public function getAll()
    {
        return new User();
    }

    public function update(Request $request, User $user)
    {

        $updatedUser = User::where('id', $user->id)->update([



            'father_name' => $request->father_name,
            'mother_name' => $request->mother_name,
            'phone' => $request->phone,
            'address' => $request->address,
            'designation' => $request->designation,
            'user_name'=>$request->user_name

        ]);
        return $updatedUser;
    }

    public function updatePassword(Request $request, User $user)
    {
        try {
            if (Hash::check($request->old_password, $user->password)) {
                $user->update(['password' => bcrypt($request->new_password)]);
                return 1;
            } else {
                return 0;
            }
        } catch (\Exception $e) {
            return 0;
        }

    }

    public function prepareForDataTable(Builder $dataBuilder, Request $request)
    {
        $start = $request->get('start');
        $length = $request->get('length');
        $draw = $request->get('draw');

        $data = $dataBuilder->paginate($length, ['*'], null, (int)$start / $length + 1);

        $response = [
            'draw' => $draw,
            'recordsTotal' => $data->total(),
            'recordsFiltered' => $data->total(),
            'data' => []
        ];

        $index = 1;

        $data->each(function ($data) use (&$response, &$index) {

            $roles = [];
            foreach ($data->roles()->pluck('name') as $role) {
                $roles [] = $role;
            }
            $response['data'][] = [
                'sl' => $index,
                'id' => $data['id'],
                'name' => $data['name'],
                'user_name' => $data['user_name'],
                'email' => $data['email'],
                'roles' => $roles,
                'contact_number' => $data ['contact_number'],
            ];
            $index++;
        });
        return $response;

    }
    public static function approverlist($approver_list)
    {
        $data=[];
        foreach($approver_list as $list)
        {
            $data[]=[
                'id'=>$list->id,
                'user_name'=>$list->user_name,
                'email'=>$list->email,
                'zone'=>$list->zone->name,
                'tth_id'=>$list->tth_id


            ];
        }
        return $data;
    }


    public static function checkIfAdmin($user_id){
        return TthUser::find($user_id)->is_admin;
    }


    public static function createToken($user){

        $token = Str::upper(Str::random(6));
        $updateduser = User::where('id', $user->id)->update([
            'reset_token' => $token
        ]);

        Mail::to($user->email)->send(new PasswordResetToken($token,$user));

        return $token;
    }



}
