@extends('admin.layouts.layout')

@section('title')
    Users List | Suzuki Admin Panel
@endsection

@section('page-specific-css')
    <link href="{{ asset('plugins/sweet-alert2/sweetalert2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('page-heading')
    User List
@endsection

@section('right-side-button')
    <a type="button" class="btn btn-default  waves-effect waves-light" href="{{ route('users.create') }}">
        <span class="btn-label"><i class="fa fa-plus-circle"></i></span>Add New User
    </a>
@endsection
@section('breadcumb')

    <li class="breadcrumb-item active">Role</li>
@endsection

@section('content')
    <div class="row">
        <div class="col-12">
            @if ($message = Session::get('success'))
                <div class="alert alert-success">
                    <p>{{ $message }}</p>
                </div>
            @endif
            <div class="card-box table-responsive">
                <table id="responsive-datatable" class="table table-bordered table-bordered dt-responsive nowrap"
                       cellspacing="0" width="100%">
                    <thead>
                    <tr>
                        <th>SL.</th>
                        <th>Name</th>
                        <th>User ID</th>
                        <th>Email</th>
                        <th>Contact</th>
                        <th>Role</th>
                        <th width="280px">Action</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($users as $user)
                        <tr>
                            <td> {{ ++$i }}</td>
                            <td> {{ $user->name }}</td>
                            <td> {{ $user->user_name }}</td>
                            <td> {{ $user->email }}</td>
                            <td> {{ $user->contact_number }}</td>
                            <td>
                                @if(!empty($user->roles))
                                    @foreach($user->roles as $role)
                                        <label class="label label-info">{{ $role->name }}</label>
                                    @endforeach
                                @endif
                            </td>
                            <td>
                                @can('User-Manage')
                                    <a class="btn btn-success" href="{{ route('users.edit',$user->id) }}"><i
                                                class="fa fa-edit"></i></a>
                                @endcan
                                @can('User-Manage')
                                    <form id="del_user_form" action="{{ route('users.destroy',$user->id) }}"
                                          method="post"
                                          style="display: inline;">
                                        {!! method_field('delete') !!}
                                        {{ csrf_field() }}
                                        <button class="btn btn-danger" type="submit" id="del_user"><i
                                                    class="fa fa-remove"></i></button>
                                    </form>
                                @endcan
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                {!! $users->render() !!}
            </div>
        </div>
    </div>
@endsection


@section('page-specific-js')
    @parent
    <script src="{{ asset('plugins/multiselect/js/jquery.multi-select.js') }}"></script>
    <script src="{{ asset('plugins/sweet-alert2/sweetalert2.min.js') }}"></script>
    <script>
        $("#permissions").multiSelect();

        $("#del_user").on('click', function (e) {
            e.preventDefault();
            swal({
                title: 'Warning',
                text: "Do you want to delete this user?",
                type: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Yes'
            }).then((result) => {
                if (result) {
                    $("#del_user_form").submit();
                }
            });
        });
    </script>

@endsection
