@extends('admin.layouts.layout')

@section('title')
    Role List | Suzuki Admin Panel
@endsection

@section('page-specific-css')
    <link href="{{ asset('plugins/datatables/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css"/>
    <link href="{{ asset('plugins/datatables/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css"/>
    <link href="{{ asset('plugins/sweet-alert2/sweetalert2.min.css') }}" rel="stylesheet" type="text/css"/>
@endsection

@section('page-heading')
    Roles List
@endsection

@section('right-side-button')
    <a type="button" class="btn btn-default  waves-effect waves-light" href="{{ route('roles.create') }}">
        <span class="btn-label"><i class="fa fa-plus-circle"></i></span>Add New Role
    </a>
@endsection
@section('breadcumb')

    <li class="breadcrumb-item active">Role</li>
@endsection

@section('content')
    <div class="row">
        <div class="col-12">
            @if ($message = Session::get('success'))
                <div class="alert alert-success">
                    <p>{{ $message }}</p>
                </div>
            @endif
            <div class="card-box table-responsive">
                <table id="responsive-datatable" class="table table-bordered table-bordered dt-responsive nowrap"
                       cellspacing="0" width="100%">
                    <thead>
                    <tr>
                        <th>SL.</th>
                        <th>Name</th>
                        <th width="280px">Action</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($roles as $role)
                        <tr>
                            <td> {{ ++$i }}</td>
                            <td> {{ $role->name }}</td>
                            <td>
                                <a class="btn btn-info" href="{{ route('roles.show',$role->id) }}"><i
                                            class="fa fa-eye"></i></a>
                                @can('Role-Manage')
                                <a class="btn btn-success" href="{{ route('roles.edit',$role->id) }}"><i
                                            class="fa fa-edit"></i></a>
                                @endcan
                                @can('Role-Manage')
                                <form id="del_role_form" action="{{ route('roles.destroy',$role->id) }}" method="post" style="display: inline;">
                                    {!! method_field('delete') !!}
                                    {{ csrf_field() }}
                                    <button class="btn btn-danger" type="submit" id="del_role"><i
                                                class="fa fa-remove"></i></button>
                                </form>
                                @endcan
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                {!! $roles->render() !!}
            </div>
        </div>
    </div>
@endsection


@section('page-specific-js')
    @parent
    <script src="{{ asset('plugins/sweet-alert2/sweetalert2.min.js') }}"></script>
    <script>
        $("#del_role").on('click',function (e) {
            e.preventDefault();
            swal({
                title: 'Warning',
                text: "Do you want to delete this user?",
                type: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Yes'
            }).then((result) => {
                if (result) {
                    $("#del_role_form").submit();
                }
            });
        });
    </script>

@endsection
